TaggableStore class abstract
Mixin-like base class that exposes tag-scoped cache repositories.
A concrete store extends this class when tagged keys should be isolated by
version identifiers. The implementation assumes the concrete object also
implements Store; it is intended for the package's cache stores.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
Creates a
TaggedCacheinstance with the specified tags. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited